searchData={"items":[{"type":"module","title":"Airbrake","doc":"This module provides functions to report any kind of exception to\n[Airbrake](https://airbrake.io/) or [Errbit](http://errbit.com/).\n\n`Airbrake.report/2` can be used to report directly to Airbrake.io.\n`Airbrake.Plug` and `Airbrake.Channel` can be used to automatically report\nerrors from controllers or channels.\n\nSee [README](readme.html) for configuration and usage instructions.","ref":"Airbrake.html"},{"type":"function","title":"Airbrake.monitor/1","doc":"Monitor exceptions in the target process.\n\nIf you don't want system-wide monitoring, but would like to monitor one specific process,\nthen you could use `Airbrake.monitor/1`\n\nExamples:\n\nWith a given PID:\n    Airbrake.monitor(pid)\nWith a registered process:\n    Airbrake.monitor(Registered.Process.Name)\nWith `spawn/1` and its counterparts:\n    spawn(fn ->\n      :timer.sleep(500)\n      String.upcase(nil)\n    end) |> Airbrake.monitor","ref":"Airbrake.html#monitor/1"},{"type":"function","title":"Airbrake.report/2","doc":"Send a report to Airbrake about given exception.\n\n`exception` could be Exception.t or a keywords list with two keys :type & :message\n\n`options` is a keywords list with following keys:\n  * :params - use it to pass request params\n  * :context - use it to pass detailed information about the exceptional situation\n  * :session - use it to pass info about user session\n  * :env - use it to pass environment variables, headers and so on\n  * :stacktrace - use it when you would like send something different than System.stacktrace\n\nThis function will always return `:ok` right away and perform the reporting of the given exception in the background.","ref":"Airbrake.html#report/2"},{"type":"function","title":"Examples - Airbrake.report/2","doc":"Exceptions can be reported directly:\n    Airbrake.report(ArgumentError.exception(\"oops\"))\n    #=> :ok\nOften, you'll want to report something you either rescued or caught.\n\nFor rescued exceptions:\n    try do\n      raise ArgumentError, \"oops\"\n    rescue\n      exception ->\n        Airbrake.report(exception)\n        # You can also reraise the exception here with reraise/2\n    end\nFor caught exceptions:\n    try do\n      throw(:oops)\n      # or exit(:oops)\n    catch\n      kind, value ->\n        Airbrake.report([type: kind, message: inspect(value)])\n    end\nUsing custom data:\n    Airbrake.report(\n      [type: \"DebugInfo\", message: \"Something went wrong\"],\n      context: %{\n        moon_phase: \"eclipse\"\n      })","ref":"Airbrake.html#report/2-examples"},{"type":"module","title":"Airbrake.Channel","doc":"Reports errors encountered on a channel.\n\n```elixir\ndef YourApp.Web do\n  # ...\n  def channel do\n    quote do\n      use Phoenix.Channel\n      use Airbrake.Channel\n      # ...\n    end\n  end\n  # ...\nend\n```\n\nSee the [README](readme.html) for configuration options.","ref":"Airbrake.Channel.html"},{"type":"module","title":"Airbrake.GenServer","doc":"This module provides the ability to monitor workers of your gen.servers,\njust write `use Airbrake.GenServer` instead of `use GenServer`\nand any time when GenServer would be terminated for a some reason you will know about it.\n\nCould be used in case when you don't want a system-wide reporting.","ref":"Airbrake.GenServer.html"},{"type":"function","title":"Airbrake.GenServer.handle_terminate/2","doc":"Implements a set of reporting rules based on process termination reason.\nCould be overridden if you want to.","ref":"Airbrake.GenServer.html#handle_terminate/2"},{"type":"module","title":"Airbrake.Plug","doc":"Reports any error encountered in the plug pipeline.\n\nTo use this plug, add it to your router:\n\n```elixir\ndefmodule YourApp.Router do\n  use Phoenix.Router\n  use Airbrake.Plug\n  # ...\nend\n```\n\nSee the [README](readme.html) for configuration options.","ref":"Airbrake.Plug.html"},{"type":"extras","title":"Airbrake Client","doc":"# Airbrake Client\n\nCapture exceptions and send them to [Airbrake](http://airbrake.io) or to\nyour [Errbit](http://errbit.com/) installation.\n\nThis library was originally forked from the\n[`airbrake`](https://hex.pm/packages/airbrake) Hex package.  Development and\nsupport for that library seems to have lapsed, but we (the devs at\n[CityBase](https://thecitybase.com/)) had changes and updates we wanted to make.\nSo we decided to publish our own fork of the library.","ref":"readme.html"},{"type":"extras","title":"Installation - Airbrake Client","doc":"Add `airbrake_client` to your dependencies:\n\n```elixir\ndefp deps do\n  [\n    {:airbrake_client, \"~> 0.10\"}\n  ]\nend\n```\n\n#","ref":"readme.html#installation"},{"type":"extras","title":"Migrating from `airbrake` - Airbrake Client","doc":"If you are switching from the original `airbrake` library:\n\n1. Replace the `:airbrake` dependency with the `:airbrake_client` dependency\n   above.\n    * You may want to start with version `~> 0.8.0` for maximum backwards\n      compatibility.\n1. Remove the `airbrake` dependency in your lockfile.\n    * Command: `mix deps.unlock --unused`\n    * If the dependency remains in the lockfile, check _all_ of your apps and\n      _all_ of your dependencies.\n1. Update your `config/*.exs` files to configure `:airbrake_client` instead of\n   `:airbrake`.\n    * A search-and-replace-in-project on `config :airbrake` can work really well.\n    * When you run your project(even running the tests), you should get a\n      complaint if you're still configuring `:airbrake`.","ref":"readme.html#migrating-from-airbrake"},{"type":"extras","title":"Configuration - Airbrake Client","doc":"```elixir\nconfig :airbrake_client,\n  api_key: System.get_env(\"AIRBRAKE_API_KEY\"),\n  project_id: System.get_env(\"AIRBRAKE_PROJECT_ID\"),\n  environment: Mix.env(),\n  filter_parameters: [\"password\"],\n  filter_headers: [\"authorization\"],\n  session: :include_logger_metadata,\n  host: \"https://api.airbrake.io\" # or your Errbit host\n\nconfig :logger,\n  backends: [{Airbrake.LoggerBackend, :error}, :console]\n```\n\nSplit this config across your `config/*.exs` files (especially the runtime\nsetting in `config/runtime.exs`).\n\nRequired configuration arguments:\n\n  * `:api_key` - (binary) the token needed to access the [Airbrake\n    API](https://airbrake.io/docs/api/). You can find it in [User\n    Settings](https://airbrake.io/users/edit).\n  * `:project_id` - (integer) the id of your project at Airbrake.\n\nOptional configuration arguments:\n\n  * `:environment` - (binary or function returning binary) the environment that\n    will be attached to each reported exception.\n  * `:filter_parameters` - (list of binaries) allows to filter out sensitive\n    parameters such as passwords and tokens.\n  * `:filter_headers` - (list of binaries) filters HTTP headers.\n  * `:host` - (binary) the URL of the HTTP host; defaults to\n    `https://api.airbrake.io`.\n  * `:ignore` - (MapSet of binary or function returning boolean or :all) allows\n    to ignore some or all exceptions.  See examples below.\n  * `:options` - (keyword list or function returning keyword list) values that\n    are included in all reports to Airbrake.io.  See examples below.\n  * `:session` - can be set to `:include_logger_metadata` to include Logger\n    metadata in the `session` field of the report; omit this option if you do\n    not want Logger metadata.  See below for more information.\n\n#","ref":"readme.html#configuration"},{"type":"extras","title":"Logger metadata in the `session` - Airbrake Client","doc":"If you set the `:session` config to `:include_logger_metadata`, the Logger\nmetadata from the process that invokes `Airbrake.report/2` will be the initial\nsession data for the `session` field.  The values passed as `:session` in the\n`options` parameter of `Airbrake.report/2` are _added_ to the session value,\noverwriting any Logger metadata values.\n\nIf you do not set the `:session` config, only the `:session` value passed as the\noptions to `Airbrake.report/2` will be used for the `session` field in the\nreport.\n\nIf the `session` turns out to be empty (for whatever reason), it is instead set\nto `nil` (and should not show up in the report).\n\n#","ref":"readme.html#logger-metadata-in-the-session"},{"type":"extras","title":"Ignoring some exceptions - Airbrake Client","doc":"To ignore some exceptions use the `:ignore` config key.  The value can be a\n`MapSet`:\n\n```elixir\nconfig :airbrake_client,\n  ignore: MapSet.new([\"Custom.Error\"])\n```\n\nThe value can also be a two-argument function:\n\n```elixir\nconfig :airbrake_client,\n  ignore: fn type, message ->\n    type == \"Custom.Error\" && String.contains?(message, \"silent error\")\n  end\n```\n\nOr the value can be the atom `:all` to ignore all errors (and effectively\nturning off all reporting):\n\n```elixir\nconfig :airbrake_client,\n  ignore: :all\n```\n\n#","ref":"readme.html#ignoring-some-exceptions"},{"type":"extras","title":"Shared options for reporting data to Airbrake - Airbrake Client","doc":"If you have data that should _always_ be reported, they can be included in the\nconfig with the `:options` key.  Its value should be a keyword list with any of\nthese keys: `:context`, `:params`, `:session`, and `:env`.\n\n```elixir\nconfig :airbrake_client,\n  options: [env: %{\"SOME_ENVIRONMENT_VARIABLE\" => \"environment variable\"}]\n```\n\nAlternatively, you can specify a function (as a tuple) which returns a keyword\nlist (with the same keys):\n\n```elixir\nconfig :airbrake_client,\n  options: {Web, :airbrake_options, 1}\n```\n\nThe function takes a keyword list as its only parameter; the function arity is\nalways 1.","ref":"readme.html#shared-options-for-reporting-data-to-airbrake"},{"type":"extras","title":"Usage - Airbrake Client","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"Phoenix app - Airbrake Client","doc":"```elixir\ndefmodule YourApp.Router do\n  use Phoenix.Router\n  use Airbrake.Plug # <- put this line to your router.ex\n\n  # ...\nend\n```\n\n```elixir\n  def channel do\n    quote do\n      use Phoenix.Channel\n      use Airbrake.Channel # <- put this line to your web.ex\n      # ...\n```\n\n#","ref":"readme.html#phoenix-app"},{"type":"extras","title":"Report an exception - Airbrake Client","doc":"```elixir\ntry do\n  String.upcase(nil)\nrescue\n  exception -> Airbrake.report(exception)\nend\n```\n\n#","ref":"readme.html#report-an-exception"},{"type":"extras","title":"GenServer - Airbrake Client","doc":"Use `Airbrake.GenServer` instead of `GenServer`:\n\n```elixir\ndefmodule MyServer do\n  use Airbrake.GenServer\n  # ...\nend\n```\n\n#","ref":"readme.html#genserver"},{"type":"extras","title":"Any Elixir process - Airbrake Client","doc":"By pid:\n\n```elixir\nAirbrake.monitor(pid)\n```\n\nBy name:\n\n```elixir\nAirbrake.monitor(Registered.Process.Name)\n```","ref":"readme.html#any-elixir-process"},{"type":"extras","title":"Integration Apps - Airbrake Client","doc":"The Elixir apps defined in `integration_test_apps` are used for testing\ndifferent dependency scenarios.  If you make changes to the way `jason` or\n`poison` is used this library, you should consider adding tests to those apps.","ref":"readme.html#integration-apps"},{"type":"extras","title":"Changelog for v0.x","doc":"# Changelog for v0.x","ref":"changelog.html"},{"type":"extras","title":"v2.1.0 (??????????) - Changelog for v0.x","doc":"#","ref":"changelog.html#v2-1-0"},{"type":"extras","title":"Enhancements - Changelog for v0.x","doc":"* New config option: if `:session` is set to `:include_logger_metadata`, the\n    Logger metadata from `Logger.metadata/0` is added to the `session` field of\n    the report.  (If the option is not set, the metadata is not included.)","ref":"changelog.html#enhancements"},{"type":"extras","title":"v2.0.0 (2024-03-11) - Changelog for v0.x","doc":"#","ref":"changelog.html#v2-0-0-2024-03-11"},{"type":"extras","title":"Enhancements - Changelog for v0.x","doc":"* [Airbrake.Utils] Add `detuple/1` to support CBRelay in parsing Airbrake params before transmitting\n  * [Airbrake.Utils] Add `destruct/1` to support CBRelay in parsing Airbrake params before transmitting\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Breaking Change - Changelog for v0.x","doc":"* Drop support for Elixir <1.12","ref":"changelog.html#breaking-change"},{"type":"extras","title":"v1.0.0 (2023-10-12) - Changelog for v0.x","doc":"#","ref":"changelog.html#v1-0-0-2023-10-12"},{"type":"extras","title":"Enhancements - Changelog for v0.x","doc":"* [Airbrake.Worker] use only `Application.compile_env/3`, drop use of `Application.get_env/3`.\n  * Formatting changes.\n  * Allow version 1.X or 2.X for `httpoison`; drop support for 0.9.\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Breaking Change - Changelog for v0.x","doc":"* Drop support for Elixir <1.10.  Use must use earlier version to compile with earlier versions of Elixir.","ref":"changelog.html#breaking-change"},{"type":"extras","title":"v0.11.0 (2022-12-05) - Changelog for v0.x","doc":"* [Airbrake.Plug] Exposes `handle_errors/2` as private\n  * Fixes credo warnings","ref":"changelog.html#v0-11-0-2022-12-05"},{"type":"extras","title":"v0.10.0 (2021-07-14) - Changelog for v0.x","doc":"* [Airbrake.Payload] Support logging structs in payload.\n  * [Airbrake.Payload] Filter atom keys from maps in payload.","ref":"changelog.html#v0-10-0-2021-07-14"},{"type":"extras","title":"v0.9.1 (2021-06-08) - Changelog for v0.x","doc":"#","ref":"changelog.html#v0-9-1-2021-06-08"},{"type":"extras","title":"Enhancements - Changelog for v0.x","doc":"* [Airbrake] Updates default URL to `https://api.airbrake.io`.\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog for v0.x","doc":"* [Airbrake] Add `:filter_headers` option to filter HTTP headers included in `:environment`.\n  * [Airbrake.Payload] Conditionally derive `Jason.Encoder` if `Jason.Encoder` is defined (i.e., `jason` is a dependency).\n  * [Airbrake.Payload] Add fields `context`, `environment`, `params`, and `session` to `Airbrake.Payload`.\n  * [Airbrake.Worker] Generate a useable stacktrace when one isn't provided in the options.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"v0.9.0 (2021-06-04) - Changelog for v0.x","doc":"Fixes deprecations and improves testing.\n\n#","ref":"changelog.html#v0-9-0-2021-06-04"},{"type":"extras","title":"Enhancements - Changelog for v0.x","doc":"* [Airbrake.Worker] Abstract HTTP client for better testing using `mox`.\n  * [Airbrake.Worker] Add tests.\n  * [Airbrake.LoggerBackend] Add tests.\n  * [Airbrake.LoggerBackend] Use `@behaviour :gen_event` instead of `use GenEvent`.\n  * [mix.exs] Start dependency applications automatically.\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog for v0.x","doc":"* [Airbrake.Channel] Use `__STACKTRACE__` instead of deprecated `System.stacktrace()`.\n  * [Airbrake.Worker] Use `Process.info(self(), :current_stacktrace)` instead of deprecated `System.stacktrace()`.\n  * [Airbrake] Use child spec instead of deprecated Supervisor.Spec.worker/1.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"v0.8.2 (2021-06-03) - Changelog for v0.x","doc":"Renames the app to `:airbrake_client`.\n\n#","ref":"changelog.html#v0-8-2-2021-06-03"},{"type":"extras","title":"Bug fixes - Changelog for v0.x","doc":"* [mix.exs] Renames the app to `:airbrake_client` so that starting the app for this library is more natural.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"v0.8.1 (2021-06-02) - Changelog for v0.x","doc":"Quick documentation fix.\n\n#","ref":"changelog.html#v0-8-1-2021-06-02"},{"type":"extras","title":"Bug fixes - Changelog for v0.x","doc":"* [README.md] Use correct case when linking to `readme.html`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"v0.8.0 (2021-06-02) - Changelog for v0.x","doc":"The first official release of `airbrake_client` (forked and disconnected from [`airbrake`](https://hex.pm/packages/airbrake)).\n\n#","ref":"changelog.html#v0-8-0-2021-06-02"},{"type":"extras","title":"Enhancements - Changelog for v0.x","doc":"* [README.md] Update for new maintainers and better instructions.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Previous versions - Changelog for v0.x","doc":"The CityBase fork of `airbrake` had a [v0.7.0 release](https://github.com/CityBaseInc/airbrake-elixir/releases/tag/0.7.0), available only through GitHub.\n\nVersions 0.6.x are available as the original [`airbrake`](https://hex.pm/packages/airbrake) library.","ref":"changelog.html#previous-versions"}],"content_type":"text/markdown"}